/*
 * Synopsis:
 *	int diswui(int stream, unsigned value)
 *
 *	Converts <value> into a Data-is-Strings unsigned integer and sends it to
 *	<stream>.
 *
 *	This format for character strings representing unsigned integers can
 *	best be understood through the decoding algorithm:
 *
 *	1. Initialize the digit count to 1.
 *
 *	2. Read the next character; if it is a plus sign, go to step (4); if it
 *	   is a minus sign, post an error.
 *
 *	3. Decode a new count from the digit decoded in step (2) and the next
 *	   count - 1 digits; repeat step (2).
 *
 *	4. Decode the next count digits as the unsigned integer.
 *
 *	Returns DIS_SUCCESS if everything works well.  Returns an error code
 *	otherwise.  In case of an error, no characters are sent to <stream>.
 */

#include <pbs_config.h>   /* the master config generated by configure */

#include <assert.h>
#include <stddef.h>

#include "dis.h"
#include "dis_.h"
#undef diswui

int diswui(stream, value)
    int			stream;
    unsigned		value;
    {
	int		retval;

	assert(disw_commit != NULL);

	retval = diswui_(stream, value);
	return (((*disw_commit)(stream, retval == DIS_SUCCESS) < 0) ?
	       DIS_NOCOMMIT : retval);
}
